@@ -1,9 +1,6 @@
 package Statocles;
-{
-  $Statocles::VERSION = '0.006';
-}
 # ABSTRACT: A static site generator
-
+$Statocles::VERSION = '0.007';
 # This module exists for both documentation and to help File::Share
 # find the right share dir
 
@@ -19,7 +16,7 @@ Statocles - A static site generator
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 DESCRIPTION
 
@@ -27,7 +24,7 @@ Statocles is a tool for building static HTML pages from documents.
 
 =head2 DOCUMENTS
 
-A document is a data structure. The default store reads documents in a combined
+A L<document|Statocles::Document> is a data structure. The default store reads documents in a combined
 YAML and Markdown format.
 
 Documents are formatted with a YAML document on top, and Markdown content
@@ -41,11 +38,25 @@ on the bottom, like so:
     
     This is a paragraph
 
-This is the same format that L<http://jekyllrb.com|Jekyll> uses.
+This is the same format that L<Jekyll|http://jekyllrb.com> uses. The document
+format is described in the L<Statocles::Store> documentation under
+L<Frontmatter Document Format|Statocles::Store/"Frontmatter Document Format">.
 
 =head2 PAGES
 
-A page is rendered HTML ready to be sent to a user.
+A L<Statocles::Page> is rendered HTML ready to be sent to a user.
+
+=over 4
+
+=item L<Statocles::Page::Document>
+
+This page renders a single document.
+
+=item L<Statocles::Page::List>
+
+This page renders a list of other pages (not documents).
+
+=back
 
 =head1 APPLICATIONS
 
@@ -61,17 +72,26 @@ A simple blogging application.
 
 =head1 SITES
 
-A site manages a bunch of applications, writing and deploying the resulting
+A L<Statocles::Site> manages a bunch of applications, writing and deploying the resulting
 pages.
 
 Deploying the site may involve a simple file copy, but it could also involve a
 Git repository, an FTP site, or a database.
 
+=over 4
+
+=item L<Statocles::Site::Git>
+
+A simple Git repository site.
+
+=back
+
 =head1 STORES
 
-A store reads and writes documents and pages. The default store reads documents
-in YAML and writes pages to a file, but stores could read documents as JSON, or
-from a Mongo database, and write pages to a database, or whereever you want!
+A L<Statocles::Store> reads and writes documents and pages. The default store
+reads documents in YAML and writes pages to a file, but stores could read
+documents as JSON, or from a Mongo database, and write pages to a database, or
+whereever you want!
 
 =head1 AUTHOR
 
