@@ -1,24 +1,13 @@
 package Statocles::Site::Git;
-{
-  $Statocles::Site::Git::VERSION = '0.006';
-}
 # ABSTRACT: A git-based site
-
+$Statocles::Site::Git::VERSION = '0.007';
 use Statocles::Class;
 extends 'Statocles::Site';
 
-use File::Find qw( find );
 use File::Copy::Recursive qw( dircopy );
 use Git::Repository;
 
 
-has deploy_dir => (
-    is => 'ro',
-    isa => Str,
-    default => sub { '.' },
-);
-
-
 has deploy_branch => (
     is => 'ro',
     isa => Str,
@@ -32,19 +21,20 @@ sub deploy {
     my $build_dir = $self->build_store->path;
     my $deploy_dir = $self->deploy_store->path;
 
-    my $git = Git::Repository->new( work_tree => $deploy_dir );
+    my $git = Git::Repository->new( work_tree => "$deploy_dir" );
 
     my $current_branch = _current_branch( $git );
 
     $self->write( $self->build_store );
     my @files;
-    find( sub {
-        if ( -f ) {
-            my $name = $File::Find::name;
-            $name =~ s/$build_dir/$deploy_dir/;
+    my $iter = $build_dir->iterator( { recurse => 1, follow_symlinks => 1 } );
+    while ( my $path = $iter->() ) {
+        if ( $path->is_file ) {
+            my $name = "$path";
+            $name =~ s/\Q$build_dir/$deploy_dir/;
             push @files, $name;
         }
-    }, $build_dir );
+    };
 
     if ( !_has_branch( $git, $self->deploy_branch ) ) {
         _git_run( $git, checkout => -b => $self->deploy_branch );
@@ -53,7 +43,7 @@ sub deploy {
         _git_run( $git, checkout => $self->deploy_branch );
     }
 
-    dircopy( $build_dir, $deploy_dir );
+    dircopy( "$build_dir", "$deploy_dir" );
     _git_run( $git, add => @files );
     _git_run( $git, commit => -m => 'Site update' );
     _git_run( $git, checkout => $current_branch );
@@ -64,8 +54,8 @@ sub deploy {
 sub _git_run {
     my ( $git, @args ) = @_;
     my $cmd = $git->command( @args );
-    my $stdout = readline $cmd->stdout;
-    my $stderr = readline $cmd->stderr;
+    my $stdout = readline( $cmd->stdout ) // '';
+    my $stderr = readline( $cmd->stderr ) // '';
     $cmd->close;
     if ( my $exit = $cmd->exit ) {
         warn "git $args[0] exited with $exit\n-- STDOUT --\n$stdout\n-- STDERR --\n$stderr\n";
@@ -96,7 +86,7 @@ Statocles::Site::Git - A git-based site
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 DESCRIPTION
 
@@ -104,10 +94,6 @@ This site deploys to a Git repository.
 
 =head1 ATTRIBUTES
 
-=head2 deploy_dir
-
-The directory of the Git repository to deploy to.
-
 =head2 deploy_branch
 
 The Git branch to deploy to.
