@@ -1,18 +1,14 @@
 package Statocles::Theme;
-{
-  $Statocles::Theme::VERSION = '0.006';
-}
 # ABSTRACT: Templates, headers, footers, and navigation
-
+$Statocles::Theme::VERSION = '0.007';
 use Statocles::Class;
-use File::Find qw( find );
-use File::Slurp qw( read_file );
 use File::Share qw( dist_dir );
 
 
 has source_dir => (
     is => 'ro',
-    isa => Str,
+    isa => Path,
+    coerce => Path->coercion,
 );
 
 
@@ -29,7 +25,7 @@ around BUILDARGS => sub {
     my $args = $self->$orig( @args );
     if ( $args->{source_dir} && $args->{source_dir} =~ /^::/ ) {
         my $name = substr $args->{source_dir}, 2;
-        $args->{source_dir} = catdir( dist_dir( 'Statocles' ), 'theme', $name );
+        $args->{source_dir} = Path::Tiny->new( dist_dir( 'Statocles' ) )->child( 'theme', $name );
     }
     return $args;
 };
@@ -38,24 +34,16 @@ around BUILDARGS => sub {
 sub read {
     my ( $self ) = @_;
     my %tmpl;
-    find(
-        sub {
-            if ( /[.]tmpl$/ ) {
-                my ( $vol, $dirs, $name ) = splitpath( $File::Find::name );
-                $name =~ s/[.]tmpl$//;
-                my @dirs = splitdir( $dirs );
-                # $dirs will end with a slash, so the last item in @dirs is ''
-                my $group = $dirs[-2];
-                # $File::Find::name has / as dirsep even on Windows. Normalize
-                # so that our tests always have the OS dirsep
-                my $fullname = catpath( $vol, $dirs, "$name.tmpl" );
-                $tmpl{ $group }{ $name } = Statocles::Template->new(
-                    path => $fullname,
-                );
-            }
-        },
-        $self->source_dir,
-    );
+    my $iter = $self->source_dir->iterator({ recurse => 1, follow_symlinks => 1 });
+    while ( my $path = $iter->() ) {
+        if ( $path =~ /[.]tmpl$/ ) {
+            my $name = $path->basename( '.tmpl' ); # remove extension
+            my $group = $path->parent->basename;
+            $tmpl{ $group }{ $name } = Statocles::Template->new(
+                path => $path,
+            );
+        }
+    }
     return \%tmpl;
 }
 
@@ -77,7 +65,7 @@ Statocles::Theme - Templates, headers, footers, and navigation
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -93,9 +81,11 @@ version 0.006
 
 =head1 DESCRIPTION
 
-A Theme contains all the templates that applications need.
+A Theme contains all the L<templates|Statocles::Template> that
+L<applications|Statocles::App> need. This class handles finding and parsing
+files into L<template objects|Statocles::Template>.
 
-When the C<source_dir> is read, the templates inside are organized based on
+When the L</source_dir> is read, the templates inside are organized based on
 their name and their parent directory.
 
 =head1 ATTRIBUTES
@@ -119,11 +109,13 @@ Handle the source_dir :: share theme.
 
 =head2 read()
 
-Read the C<source_dir> and create the Statocles::Template objects inside.
+Read the C<source_dir> and create the L<template|Statocles::Template> objects
+inside.
 
 =head2 template( $section => $name )
 
-Get the template from the given C<section> with the given C<name>.
+Get the L<template|Statocles::Template> from the given C<section> with the
+given C<name>.
 
 =head1 AUTHOR
 
